/****************************************************************************
 *   $Id:: adctest.c 3623 2010-06-01 17:39:19Z usb00423                     $
 *   Project: NXP LPC13xx ADC example
 *
 *   Description:
 *     This file contains ADC test modules, main entry, to test ADC APIs.
 *
 ****************************************************************************
 * Software that is described herein is for illustrative purposes only
 * which provides customers with programming information regarding the
 * products. This software is supplied "AS IS" without any warranties.
 * NXP Semiconductors assumes no responsibility or liability for the
 * use of the software, conveys no license or title under any patent,
 * copyright, or mask work right to the product. NXP Semiconductors
 * reserves the right to make changes in the software without
 * notification. NXP Semiconductors also make no representation or
 * warranty that such application will be suitable for the specified
 * use without further testing or modification.
****************************************************************************/
#include "LPC13xx.h"                        /* LPC13xx definitions */
#include "adc.h"
#include "timer32.h"
#if ADC_DEBUG
#include "uart.h"
#endif

#define TIME_INTERVAL	((SystemFrequency/LPC_SYSCON->SYSAHBCLKDIV)/100 - 1)

extern volatile uint32_t ADCValue[ADC_NUM];
extern volatile uint32_t ADCIntDone;

#if ADC_DEBUG
extern volatile uint32_t UARTCount;
extern volatile uint8_t UARTBuffer[BUFSIZE];

uint8_t ConvertDigital ( uint8_t digital )
{
  uint8_t ascii_char;

  if ( (digital >= 0) && (digital <= 9) )
  {
	ascii_char = digital + 0x30;	/* 0~9 */
  }
  else
  {
	ascii_char = digital - 0x0A;
	ascii_char += 0x41;				/* A~F */
  }
  return ( ascii_char );
}
#endif

/******************************************************************************
**   Main Function  main()
******************************************************************************/
int main (void)
{  
  SystemInit();

  UARTInit(115200);

  /* Initialize ADC  */
  ADCInit( ADC_CLK );

  init_timer32(0, TIME_INTERVAL);
  enable_timer32(0);

  while(1)
  {
	delay32Ms(0,100);
	ADCValue[7] = ADCRead( 7 );	
	LPC_UART->IER = IER_THRE | IER_RLS;			/* Disable RBR */
	UARTBuffer[0] = ConvertDigital( (uint8_t)(ADCValue[7]>>28));
	UARTBuffer[1] = ConvertDigital( (uint8_t)((ADCValue[7]>>24)&0xF));
	UARTBuffer[2] = ConvertDigital( (uint8_t)((ADCValue[7]>>20)&0xF));
	UARTBuffer[3] = ConvertDigital( (uint8_t)((ADCValue[7]>>16)&0xF));
	UARTBuffer[4] = ConvertDigital( (uint8_t)((ADCValue[7]>>12)&0xF));
	UARTBuffer[5] = ConvertDigital( (uint8_t)((ADCValue[7]>>8)&0xF));
	UARTBuffer[6] = ConvertDigital( (uint8_t)((ADCValue[7]>>4)&0xF));
	UARTBuffer[7] = ConvertDigital( (uint8_t)(ADCValue[7]&0xF));
	UARTBuffer[8] = '\r';
	UARTBuffer[9] = '\n';
	UARTSend( (uint8_t *)UARTBuffer, 10 );
	LPC_UART->IER = IER_THRE | IER_RLS | IER_RBR;	/* Re-enable RBR */
  }

}

/******************************************************************************
**                            End Of File
******************************************************************************/

