/****************************************************************************
 *   $Id:: mscuser.c 3632 2010-06-01 22:54:42Z usb00423                     $
 *   Project: NXP LPC13xx USB MSC ROM version example
 *
 *   Description:
 *     This file contains basic USB MSC(Mass Storage Class) APIs.
 *
 ****************************************************************************
 * Software that is described herein is for illustrative purposes only
 * which provides customers with programming information regarding the
 * products. This software is supplied "AS IS" without any warranties.
 * NXP Semiconductors assumes no responsibility or liability for the
 * use of the software, conveys no license or title under any patent,
 * copyright, or mask work right to the product. NXP Semiconductors
 * reserves the right to make changes in the software without
 * notification. NXP Semiconductors also make no representation or
 * warranty that such application will be suitable for the specified
 * use without further testing or modification.
****************************************************************************/
#include "lpc13xx.h"
#include "type.h"
#include "usb.h"
#include "mscuser.h"


uint8_t  Memory[MSC_MemorySize];  /* MSC RAM */

const uint8_t InquiryStr[] = {'K','e','i','l',' ',' ',' ',' ',     \
                           'L','P','C','1','3','x','x',' ',     \
                           'D','i','s','k',' ',' ',' ',' ',     \
                           '1','.','0',' ',};

/*
 *  MSC Memory Read Callback
 *   Called automatically on Memory Read Event
 *    Parameters:      offset, destination array, and length
 *    Return Value:    None
 */
void MSC_MemoryRead (uint32_t offset, uint8_t dst[], uint32_t length) {
  uint32_t n;

  for (n = 0; n<length; n++)
  {
    dst[n] = Memory[offset+n];
  }
}

/*
 *  MSC Memory Write Callback
 *   Called automatically on Memory Write Event
 *    Parameters:      offset, source array, and length
 *    Return Value:    None
 */
void MSC_MemoryWrite (uint32_t offset, uint8_t src[], uint32_t length) {
  uint32_t n;

  for (n = 0; n<length; n++)
  {
    Memory[offset+n] = src[n];
  }
}
