/****************************************************************************
 *   $Id:: systicktest.c 3632 2010-06-01 22:54:42Z usb00423                 $
 *   Project: NXP LPC13xx Systick example
 *
 *   Description:
 *     This file contains System tick test modules, main entry, to test 
 *     systick APIs.
 *
 ****************************************************************************
 * Software that is described herein is for illustrative purposes only
 * which provides customers with programming information regarding the
 * products. This software is supplied "AS IS" without any warranties.
 * NXP Semiconductors assumes no responsibility or liability for the
 * use of the software, conveys no license or title under any patent,
 * copyright, or mask work right to the product. NXP Semiconductors
 * reserves the right to make changes in the software without
 * notification. NXP Semiconductors also make no representation or
 * warranty that such application will be suitable for the specified
 * use without further testing or modification.
****************************************************************************/
#include "LPC13xx.h"                        /* LPC13xx definitions */
#include "gpio.h"

#define SYSTICK_DELAY		5000

volatile uint32_t TimeTick = 0;

/* SysTick interrupt happens every 10 ms */
void SysTick_Handler(void)
{
  TimeTick++;
}

void delaySysTick(uint32_t tick)
{
  uint32_t timetick;

  /* Clear SysTick Counter */
  SysTick->VAL = 0;
  /* Enable the SysTick Counter */
  SysTick->CTRL |= SYSTICK_ENABLE;

  timetick = TimeTick;
  while ((TimeTick - timetick) < tick);
  
  /* Disable SysTick Counter */
  SysTick->CTRL &= ~SYSTICK_ENABLE;
  /* Clear SysTick Counter */
  SysTick->VAL = 0;
  return;
}

/* Main Program */
int main (void) {

  SystemInit();

  /* Called for system library in core_cmx.h(x=0 or 3). */
  SysTick_Config( SYSTICK_DELAY );
  
  if ( !(SysTick->CTRL & (1<<SYSTICK_CLKSOURCE)) )
  {
	/* When external reference clock is used(CLKSOURCE in
	Systick Control and register bit 2 is set to 0), the 
	SYSTICKCLKDIV must be a non-zero value and 2.5 times 
	faster than the reference clock. 
	When core clock, or system AHB clock, is used(CLKSOURCE 
	in Systick Control and register bit 2 is set to 1), the 
	SYSTICKCLKDIV has no effect to the SYSTICK frequency. See 
	more on Systick clock and status register in Cortex-M3 
	rechnical Reference Manual. */
	LPC_SYSCON->SYSTICKCLKDIV = 0x08;
  }

  /* Enable AHB clock to the GPIO domain. */
  LPC_SYSCON->SYSAHBCLKCTRL |= (1<<6);

  /* If test ARM trace capability, enabled below three lines. */
#if 0
  /* ARM trace clock = Main clock / 2 */
  LPC_SYSCON->TRACECLKDIV = 0x2;

  LPC_IOCON->PIO0_9 &= ~0x07;	
  LPC_IOCON->PIO0_9 |= 0x03;		/* ARM_TRACE_SWV */
#endif

  /* Set port 2_10 to output */
  GPIOSetDir( 2, 10, 1 );

  while (1)                                /* Loop forever */
  {
	delaySysTick(SYSTICK_DELAY);
	GPIOSetValue( 2, 10, 0 );
	delaySysTick(SYSTICK_DELAY);
	GPIOSetValue( 2, 10, 1 );
  }
}
